summary refs log tree commit diff stats
path: root/lib/system/gc_common.nim
diff options
context:
space:
mode:
Diffstat (limited to 'lib/system/gc_common.nim')
-rw-r--r--lib/system/gc_common.nim4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/system/gc_common.nim b/lib/system/gc_common.nim
index 013dc55f8..a4676d26e 100644
--- a/lib/system/gc_common.nim
+++ b/lib/system/gc_common.nim
@@ -91,7 +91,7 @@ when allowForeignThreadGc:
     ## this thread will only be initialized once per thread, no matter how often
     ## it is called.
     ##
     ## This function is availble only when ``--threads:on`` and ``--tlsEmulation:off``
     ## switches are used
     if not localGcInitialized:
       localGcInitialized = true
@@ -100,7 +100,7 @@ when allowForeignThreadGc:
       initGC()
 else:
   template setupForeignThreadGc*(): stmt =
-    {.error: "setupForeignThreadGc is availble only when ``--threads:on`` and ``--tlsEmulation:off`` are used".}
+    {.error: "setupForeignThreadGc is available only when ``--threads:on`` and ``--tlsEmulation:off`` are used".}
 
 # ----------------- stack management --------------------------------------
 #  inspired from Smart Eiffel
@@ -91,7 +91,7 @@ when allowForeignThreadGc:
     ## it is called.
     ##
-    ## This function is availble only when ``--threads:on`` and ``--tlsEmulation:off``
+    ## This function is available only when ``--threads:on`` and ``--tlsEmulation:off``
     ## switches are used
     if not localGcInitialized: